# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/controller_manager_msgs/srv/set_hardware_component_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_jazzy_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/jazzy/controller_manager_msgs/srv/set_hardware_component_state.proto\x12\x36make87_messages_ros2.jazzy.controller_manager_msgs.srv\x1a\x39make87_messages_ros2/jazzy/lifecycle_msgs/msg/state.proto\"|\n SetHardwareComponentStateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\x0ctarget_state\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.lifecycle_msgs.msg.State\"t\n!SetHardwareComponentStateResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x43\n\x05state\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.controller_manager_msgs.srv.set_hardware_component_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETHARDWARECOMPONENTSTATEREQUEST']._serialized_start=208
  _globals['_SETHARDWARECOMPONENTSTATEREQUEST']._serialized_end=332
  _globals['_SETHARDWARECOMPONENTSTATERESPONSE']._serialized_start=334
  _globals['_SETHARDWARECOMPONENTSTATERESPONSE']._serialized_end=450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_workcell_msgs/msg/workcell_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rmf_workcell_msgs/msg/workcell_result.proto\x12\x30make87_messages_ros2.jazzy.rmf_workcell_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\x92\x01\n\x0eWorkcellResult\x12\x45\n\x04time\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x14\n\x0crequest_guid\x18\x02 \x01(\t\x12\x13\n\x0bsource_guid\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_workcell_msgs.msg.workcell_result_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WORKCELLRESULT']._serialized_start=187
  _globals['_WORKCELLRESULT']._serialized_end=333
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import accel_pb2 as _accel_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as _twist_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CartesianPoint(_message.Message):
    __slots__ = ["header", "pose", "velocity", "acceleration"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pose: _pose_pb2.Pose
    velocity: _twist_pb2.Twist
    acceleration: _accel_pb2.Accel
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., velocity: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ..., acceleration: _Optional[_Union[_accel_pb2.Accel, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleInconsistencyRange(_message.Message):
    __slots__ = ["lower", "upper"]
    LOWER_FIELD_NUMBER: _ClassVar[int]
    UPPER_FIELD_NUMBER: _ClassVar[int]
    lower: int
    upper: int
    def __init__(self, lower: _Optional[int] = ..., upper: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/nav_velned.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/nav_velned.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\x96\x01\n\tNavVELNED\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\r\n\x05vel_n\x18\x02 \x01(\x05\x12\r\n\x05vel_e\x18\x03 \x01(\x05\x12\r\n\x05vel_d\x18\x04 \x01(\x05\x12\r\n\x05speed\x18\x05 \x01(\r\x12\x0f\n\x07g_speed\x18\x06 \x01(\r\x12\x0f\n\x07heading\x18\x07 \x01(\x05\x12\r\n\x05s_acc\x18\x08 \x01(\r\x12\r\n\x05\x63_acc\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.nav_velned_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVVELNED']._serialized_start=106
  _globals['_NAVVELNED']._serialized_end=256
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/test_interface_files/msg/strings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/test_interface_files/msg/strings.proto\x12\x33make87_messages_ros2.jazzy.test_interface_files.msg\"\x9b\x03\n\x07Strings\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x1d\n\x15string_value_default1\x18\x02 \x01(\t\x12\x1d\n\x15string_value_default2\x18\x03 \x01(\t\x12\x1d\n\x15string_value_default3\x18\x04 \x01(\t\x12\x1d\n\x15string_value_default4\x18\x05 \x01(\t\x12\x1d\n\x15string_value_default5\x18\x06 \x01(\t\x12\x1c\n\x14\x62ounded_string_value\x18\x07 \x01(\t\x12%\n\x1d\x62ounded_string_value_default1\x18\x08 \x01(\t\x12%\n\x1d\x62ounded_string_value_default2\x18\t \x01(\t\x12%\n\x1d\x62ounded_string_value_default3\x18\n \x01(\t\x12%\n\x1d\x62ounded_string_value_default4\x18\x0b \x01(\t\x12%\n\x1d\x62ounded_string_value_default5\x18\x0c \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.test_interface_files.msg.strings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STRINGS']._serialized_start=123
  _globals['_STRINGS']._serialized_end=534
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.derived_object_msgs.msg import solid_primitive_with_covariance_pb2 as _solid_primitive_with_covariance_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import accel_with_covariance_pb2 as _accel_with_covariance_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import polygon_pb2 as _polygon_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as _pose_with_covariance_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as _twist_with_covariance_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectWithCovariance(_message.Message):
    __slots__ = ["header", "ros2_header", "id", "detection_level", "object_classified", "pose", "twist", "accel", "polygon", "shape", "classification", "classification_certainty", "classification_age"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DETECTION_LEVEL_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASSIFIED_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    TWIST_FIELD_NUMBER: _ClassVar[int]
    ACCEL_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_CERTAINTY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_AGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    id: int
    detection_level: int
    object_classified: bool
    pose: _pose_with_covariance_pb2.PoseWithCovariance
    twist: _twist_with_covariance_pb2.TwistWithCovariance
    accel: _accel_with_covariance_pb2.AccelWithCovariance
    polygon: _polygon_pb2.Polygon
    shape: _solid_primitive_with_covariance_pb2.SolidPrimitiveWithCovariance
    classification: int
    classification_certainty: int
    classification_age: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., id: _Optional[int] = ..., detection_level: _Optional[int] = ..., object_classified: bool = ..., pose: _Optional[_Union[_pose_with_covariance_pb2.PoseWithCovariance, _Mapping]] = ..., twist: _Optional[_Union[_twist_with_covariance_pb2.TwistWithCovariance, _Mapping]] = ..., accel: _Optional[_Union[_accel_with_covariance_pb2.AccelWithCovariance, _Mapping]] = ..., polygon: _Optional[_Union[_polygon_pb2.Polygon, _Mapping]] = ..., shape: _Optional[_Union[_solid_primitive_with_covariance_pb2.SolidPrimitiveWithCovariance, _Mapping]] = ..., classification: _Optional[int] = ..., classification_certainty: _Optional[int] = ..., classification_age: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetHandEyeCalibrationPoseRequest(_message.Message):
    __slots__ = ["slot", "pose"]
    SLOT_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    slot: int
    pose: _pose_pb2.Pose
    def __init__(self, slot: _Optional[int] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class SetHandEyeCalibrationPoseResponse(_message.Message):
    __slots__ = ["success", "status", "message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status: int
    message: str
    def __init__(self, success: bool = ..., status: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Analog(_message.Message):
    __slots__ = ["pin", "domain", "state"]
    PIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    pin: int
    domain: int
    state: float
    def __init__(self, pin: _Optional[int] = ..., domain: _Optional[int] = ..., state: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WheelOdom(_message.Message):
    __slots__ = ["header", "stamp", "velocity_lin", "velocity_ang", "pose_x", "pose_y", "pose_yaw"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_LIN_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_ANG_FIELD_NUMBER: _ClassVar[int]
    POSE_X_FIELD_NUMBER: _ClassVar[int]
    POSE_Y_FIELD_NUMBER: _ClassVar[int]
    POSE_YAW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stamp: _time_pb2.Time
    velocity_lin: float
    velocity_ang: float
    pose_x: float
    pose_y: float
    pose_yaw: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., velocity_lin: _Optional[float] = ..., velocity_ang: _Optional[float] = ..., pose_x: _Optional[float] = ..., pose_y: _Optional[float] = ..., pose_yaw: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import object2271_pb2 as _object2271_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectData2271(_message.Message):
    __slots__ = ["header", "ibeo_header", "start_scan_timestamp", "scan_number", "number_of_objects", "object_list"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    START_SCAN_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCAN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    start_scan_timestamp: _time_pb2.Time
    scan_number: int
    number_of_objects: int
    object_list: _containers.RepeatedCompositeFieldContainer[_object2271_pb2.Object2271]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., start_scan_timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., scan_number: _Optional[int] = ..., number_of_objects: _Optional[int] = ..., object_list: _Optional[_Iterable[_Union[_object2271_pb2.Object2271, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import scan_point_pb2 as _scan_point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeasurementData(_message.Message):
    __slots__ = ["number_of_beams", "scan_points"]
    NUMBER_OF_BEAMS_FIELD_NUMBER: _ClassVar[int]
    SCAN_POINTS_FIELD_NUMBER: _ClassVar[int]
    number_of_beams: int
    scan_points: _containers.RepeatedCompositeFieldContainer[_scan_point_pb2.ScanPoint]
    def __init__(self, number_of_beams: _Optional[int] = ..., scan_points: _Optional[_Iterable[_Union[_scan_point_pb2.ScanPoint, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.object_recognition_msgs.msg import recognized_object_pb2 as _recognized_object_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RecognizedObjectArray(_message.Message):
    __slots__ = ["header", "objects", "cooccurrence"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    COOCCURRENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    objects: _containers.RepeatedCompositeFieldContainer[_recognized_object_pb2.RecognizedObject]
    cooccurrence: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., objects: _Optional[_Iterable[_Union[_recognized_object_pb2.RecognizedObject, _Mapping]]] = ..., cooccurrence: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_interfaces/srv/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rosbag2_interfaces/srv/snapshot.proto\x12\x31make87_messages_ros2.jazzy.rosbag2_interfaces.srv\"\x11\n\x0fSnapshotRequest\"#\n\x10SnapshotResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_interfaces.srv.snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SNAPSHOTREQUEST']._serialized_start=119
  _globals['_SNAPSHOTREQUEST']._serialized_end=136
  _globals['_SNAPSHOTRESPONSE']._serialized_start=138
  _globals['_SNAPSHOTRESPONSE']._serialized_end=173
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActiveFaultLatched2(_message.Message):
    __slots__ = ["header", "ros2_header", "ipma_pcan_data_range_check", "ipma_pcan_missing_msg", "vin_signal_compare_failure", "module_not_configured_error", "car_cfg_not_configured_error"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    IPMA_PCAN_DATA_RANGE_CHECK_FIELD_NUMBER: _ClassVar[int]
    IPMA_PCAN_MISSING_MSG_FIELD_NUMBER: _ClassVar[int]
    VIN_SIGNAL_COMPARE_FAILURE_FIELD_NUMBER: _ClassVar[int]
    MODULE_NOT_CONFIGURED_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAR_CFG_NOT_CONFIGURED_ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ipma_pcan_data_range_check: bool
    ipma_pcan_missing_msg: bool
    vin_signal_compare_failure: bool
    module_not_configured_error: bool
    car_cfg_not_configured_error: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ipma_pcan_data_range_check: bool = ..., ipma_pcan_missing_msg: bool = ..., vin_signal_compare_failure: bool = ..., module_not_configured_error: bool = ..., car_cfg_not_configured_error: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetAvailableModesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetAvailableModesResponse(_message.Message):
    __slots__ = ["available_modes"]
    AVAILABLE_MODES_FIELD_NUMBER: _ClassVar[int]
    available_modes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, available_modes: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HomePosition(_message.Message):
    __slots__ = ["header", "geo", "position", "orientation", "approach"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GEO_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    APPROACH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    geo: _geo_point_pb2.GeoPoint
    position: _point_pb2.Point
    orientation: _quaternion_pb2.Quaternion
    approach: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., geo: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., approach: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Switches(_message.Message):
    __slots__ = ["header", "switch0", "switch1", "switch2"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SWITCH0_FIELD_NUMBER: _ClassVar[int]
    SWITCH1_FIELD_NUMBER: _ClassVar[int]
    SWITCH2_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    switch0: bool
    switch1: bool
    switch2: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., switch0: bool = ..., switch1: bool = ..., switch2: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ROIObservationSafetyData(_message.Message):
    __slots__ = ["invalid_due_to_invalid_pixels", "invalid_due_to_variance", "invalid_due_to_overexposure", "invalid_due_to_underexposure", "invalid_due_to_temporal_variance", "invalid_due_to_outside_of_measurement_range", "invalid_due_to_retro_reflector_interference", "contamination_error", "quality_class", "slot_active"]
    INVALID_DUE_TO_INVALID_PIXELS_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_OVEREXPOSURE_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_UNDEREXPOSURE_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_TEMPORAL_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_OUTSIDE_OF_MEASUREMENT_RANGE_FIELD_NUMBER: _ClassVar[int]
    INVALID_DUE_TO_RETRO_REFLECTOR_INTERFERENCE_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    QUALITY_CLASS_FIELD_NUMBER: _ClassVar[int]
    SLOT_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    invalid_due_to_invalid_pixels: int
    invalid_due_to_variance: int
    invalid_due_to_overexposure: int
    invalid_due_to_underexposure: int
    invalid_due_to_temporal_variance: int
    invalid_due_to_outside_of_measurement_range: int
    invalid_due_to_retro_reflector_interference: int
    contamination_error: int
    quality_class: int
    slot_active: int
    def __init__(self, invalid_due_to_invalid_pixels: _Optional[int] = ..., invalid_due_to_variance: _Optional[int] = ..., invalid_due_to_overexposure: _Optional[int] = ..., invalid_due_to_underexposure: _Optional[int] = ..., invalid_due_to_temporal_variance: _Optional[int] = ..., invalid_due_to_outside_of_measurement_range: _Optional[int] = ..., invalid_due_to_retro_reflector_interference: _Optional[int] = ..., contamination_error: _Optional[int] = ..., quality_class: _Optional[int] = ..., slot_active: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Wrench(_message.Message):
    __slots__ = ["header", "force", "torque"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    TORQUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    force: _vector3_pb2.Vector3
    torque: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., force: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., torque: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PosCovGeodetic(_message.Message):
    __slots__ = ["header", "block_header", "mode", "error", "cov_latlat", "cov_lonlon", "cov_hgthgt", "cov_bb", "cov_latlon", "cov_lathgt", "cov_latb", "cov_lonhgt", "cov_lonb", "cov_hb"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    COV_LATLAT_FIELD_NUMBER: _ClassVar[int]
    COV_LONLON_FIELD_NUMBER: _ClassVar[int]
    COV_HGTHGT_FIELD_NUMBER: _ClassVar[int]
    COV_BB_FIELD_NUMBER: _ClassVar[int]
    COV_LATLON_FIELD_NUMBER: _ClassVar[int]
    COV_LATHGT_FIELD_NUMBER: _ClassVar[int]
    COV_LATB_FIELD_NUMBER: _ClassVar[int]
    COV_LONHGT_FIELD_NUMBER: _ClassVar[int]
    COV_LONB_FIELD_NUMBER: _ClassVar[int]
    COV_HB_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    mode: int
    error: int
    cov_latlat: float
    cov_lonlon: float
    cov_hgthgt: float
    cov_bb: float
    cov_latlon: float
    cov_lathgt: float
    cov_latb: float
    cov_lonhgt: float
    cov_lonb: float
    cov_hb: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., mode: _Optional[int] = ..., error: _Optional[int] = ..., cov_latlat: _Optional[float] = ..., cov_lonlon: _Optional[float] = ..., cov_hgthgt: _Optional[float] = ..., cov_bb: _Optional[float] = ..., cov_latlon: _Optional[float] = ..., cov_lathgt: _Optional[float] = ..., cov_latb: _Optional[float] = ..., cov_lonhgt: _Optional[float] = ..., cov_lonb: _Optional[float] = ..., cov_hb: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EmitterSendStringRequest(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class EmitterSendStringResponse(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: int
    def __init__(self, result: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_door_msgs/msg/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/rmf_door_msgs/msg/session.proto\x12,make87_messages_ros2.jazzy.rmf_door_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"n\n\x07Session\x12M\n\x0crequest_time\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x14\n\x0crequester_id\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_door_msgs.msg.session_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SESSION']._serialized_start=170
  _globals['_SESSION']._serialized_end=280
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import metric_family_pb2 as _metric_family_pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReadMetricsRequest(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class ReadMetricsResponse(_message.Message):
    __slots__ = ["header", "status", "metric_families", "timestamp"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    METRIC_FAMILIES_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status: _status_response_pb2.StatusResponse
    metric_families: _containers.RepeatedCompositeFieldContainer[_metric_family_pb2.MetricFamily]
    timestamp: _time_pb2.Time
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ..., metric_families: _Optional[_Iterable[_Union[_metric_family_pb2.MetricFamily, _Mapping]]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import collision_object_pb2 as _collision_object_pb2
from make87_messages_ros2.rolling.trajectory_msgs.msg import joint_trajectory_pb2 as _joint_trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AttachedCollisionObject(_message.Message):
    __slots__ = ["link_name", "object", "touch_links", "detach_posture", "weight"]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    TOUCH_LINKS_FIELD_NUMBER: _ClassVar[int]
    DETACH_POSTURE_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    link_name: str
    object: _collision_object_pb2.CollisionObject
    touch_links: _containers.RepeatedScalarFieldContainer[str]
    detach_posture: _joint_trajectory_pb2.JointTrajectory
    weight: float
    def __init__(self, link_name: _Optional[str] = ..., object: _Optional[_Union[_collision_object_pb2.CollisionObject, _Mapping]] = ..., touch_links: _Optional[_Iterable[str]] = ..., detach_posture: _Optional[_Union[_joint_trajectory_pb2.JointTrajectory, _Mapping]] = ..., weight: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TimesyncStatus(_message.Message):
    __slots__ = ["header", "remote_timestamp_ns", "observed_offset_ns", "estimated_offset_ns", "round_trip_time_ms"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REMOTE_TIMESTAMP_NS_FIELD_NUMBER: _ClassVar[int]
    OBSERVED_OFFSET_NS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_OFFSET_NS_FIELD_NUMBER: _ClassVar[int]
    ROUND_TRIP_TIME_MS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    remote_timestamp_ns: int
    observed_offset_ns: int
    estimated_offset_ns: int
    round_trip_time_ms: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., remote_timestamp_ns: _Optional[int] = ..., observed_offset_ns: _Optional[int] = ..., estimated_offset_ns: _Optional[int] = ..., round_trip_time_ms: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_action_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__action__pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_category_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__category__pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_tier_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__tier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\x1aImake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_action.proto\x1aKmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_category.proto\x1aGmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_tier.proto\"\xb9\x02\n\rDeliveryAlert\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertCategory\x12N\n\x04tier\x18\x03 \x01(\x0b\x32@.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertTier\x12\x0f\n\x07task_id\x18\x04 \x01(\t\x12R\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertAction\x12\x0f\n\x07message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.delivery_alert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELIVERYALERT']._serialized_start=343
  _globals['_DELIVERYALERT']._serialized_end=656
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadarPreHeaderStatusBlock(_message.Message):
    __slots__ = ["header", "uitelegramcount", "uicyclecount", "udisystemcountscan", "udisystemcounttransmit", "uiinputs", "uioutputs"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    UITELEGRAMCOUNT_FIELD_NUMBER: _ClassVar[int]
    UICYCLECOUNT_FIELD_NUMBER: _ClassVar[int]
    UDISYSTEMCOUNTSCAN_FIELD_NUMBER: _ClassVar[int]
    UDISYSTEMCOUNTTRANSMIT_FIELD_NUMBER: _ClassVar[int]
    UIINPUTS_FIELD_NUMBER: _ClassVar[int]
    UIOUTPUTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    uitelegramcount: int
    uicyclecount: int
    udisystemcountscan: int
    udisystemcounttransmit: int
    uiinputs: int
    uioutputs: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., uitelegramcount: _Optional[int] = ..., uicyclecount: _Optional[int] = ..., udisystemcountscan: _Optional[int] = ..., udisystemcounttransmit: _Optional[int] = ..., uiinputs: _Optional[int] = ..., uioutputs: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/fuse_msgs/srv/set_graph.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.fuse_msgs.msg import serialized_graph_pb2 as make87__messages__ros2_dot_jazzy_dot_fuse__msgs_dot_msg_dot_serialized__graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/fuse_msgs/srv/set_graph.proto\x12(make87_messages_ros2.jazzy.fuse_msgs.srv\x1a?make87_messages_ros2/jazzy/fuse_msgs/msg/serialized_graph.proto\"[\n\x0fSetGraphRequest\x12H\n\x05graph\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.fuse_msgs.msg.SerializedGraph\"4\n\x10SetGraphResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.fuse_msgs.srv.set_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETGRAPHREQUEST']._serialized_start=167
  _globals['_SETGRAPHREQUEST']._serialized_end=258
  _globals['_SETGRAPHRESPONSE']._serialized_start=260
  _globals['_SETGRAPHRESPONSE']._serialized_end=312
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReceiverTime(_message.Message):
    __slots__ = ["header", "ros2_header", "block_header", "utc_year", "utc_month", "utc_day", "utc_hour", "utc_min", "utc_second", "delta_ls", "sync_level"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    UTC_YEAR_FIELD_NUMBER: _ClassVar[int]
    UTC_MONTH_FIELD_NUMBER: _ClassVar[int]
    UTC_DAY_FIELD_NUMBER: _ClassVar[int]
    UTC_HOUR_FIELD_NUMBER: _ClassVar[int]
    UTC_MIN_FIELD_NUMBER: _ClassVar[int]
    UTC_SECOND_FIELD_NUMBER: _ClassVar[int]
    DELTA_LS_FIELD_NUMBER: _ClassVar[int]
    SYNC_LEVEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    block_header: _block_header_pb2.BlockHeader
    utc_year: int
    utc_month: int
    utc_day: int
    utc_hour: int
    utc_min: int
    utc_second: int
    delta_ls: int
    sync_level: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., utc_year: _Optional[int] = ..., utc_month: _Optional[int] = ..., utc_day: _Optional[int] = ..., utc_hour: _Optional[int] = ..., utc_min: _Optional[int] = ..., utc_second: _Optional[int] = ..., delta_ls: _Optional[int] = ..., sync_level: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as _pose_with_covariance_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg import route_precondition_pb2 as _route_precondition_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RobotInfo(_message.Message):
    __slots__ = ["header", "robot_name", "pose", "shape", "shape_variables", "sync", "mode", "status", "good_id", "order_id", "order_status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    SHAPE_VARIABLES_FIELD_NUMBER: _ClassVar[int]
    SYNC_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    GOOD_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    robot_name: str
    pose: _pose_with_covariance_pb2.PoseWithCovariance
    shape: int
    shape_variables: _containers.RepeatedScalarFieldContainer[float]
    sync: _route_precondition_pb2.RoutePrecondition
    mode: int
    status: int
    good_id: int
    order_id: int
    order_status: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., robot_name: _Optional[str] = ..., pose: _Optional[_Union[_pose_with_covariance_pb2.PoseWithCovariance, _Mapping]] = ..., shape: _Optional[int] = ..., shape_variables: _Optional[_Iterable[float]] = ..., sync: _Optional[_Union[_route_precondition_pb2.RoutePrecondition, _Mapping]] = ..., mode: _Optional[int] = ..., status: _Optional[int] = ..., good_id: _Optional[int] = ..., order_id: _Optional[int] = ..., order_status: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_control.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2
from make87_messages_ros2.rolling.visualization_msgs.msg import marker_pb2 as make87__messages__ros2_dot_rolling_dot_visualization__msgs_dot_msg_dot_marker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_control.proto\x12\x33make87_messages_ros2.rolling.visualization_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\x1a@make87_messages_ros2/rolling/visualization_msgs/msg/marker.proto\"\xd0\x02\n\x18InteractiveMarkerControl\x12\x0c\n\x04name\x18\x01 \x01(\t\x12O\n\x0borientation\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x18\n\x10orientation_mode\x18\x03 \x01(\r\x12\x18\n\x10interaction_mode\x18\x04 \x01(\r\x12\x16\n\x0e\x61lways_visible\x18\x05 \x01(\x08\x12L\n\x07markers\x18\x06 \x03(\x0b\x32;.make87_messages_ros2.rolling.visualization_msgs.msg.Marker\x12&\n\x1eindependent_marker_orientation\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.visualization_msgs.msg.interactive_marker_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_start=273
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_end=609
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerInformation(_message.Message):
    __slots__ = ["header", "cap_flags", "gimbal_device_id", "roll_min", "roll_max", "pitch_min", "pitch_max", "yaw_min", "yaw_max"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAP_FLAGS_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    ROLL_MIN_FIELD_NUMBER: _ClassVar[int]
    ROLL_MAX_FIELD_NUMBER: _ClassVar[int]
    PITCH_MIN_FIELD_NUMBER: _ClassVar[int]
    PITCH_MAX_FIELD_NUMBER: _ClassVar[int]
    YAW_MIN_FIELD_NUMBER: _ClassVar[int]
    YAW_MAX_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    cap_flags: int
    gimbal_device_id: int
    roll_min: float
    roll_max: float
    pitch_min: float
    pitch_max: float
    yaw_min: float
    yaw_max: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., cap_flags: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ..., roll_min: _Optional[float] = ..., roll_max: _Optional[float] = ..., pitch_min: _Optional[float] = ..., pitch_max: _Optional[float] = ..., yaw_min: _Optional[float] = ..., yaw_max: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Strings(_message.Message):
    __slots__ = ["string_value", "string_value_default1", "string_value_default2", "string_value_default3", "string_value_default4", "string_value_default5", "bounded_string_value", "bounded_string_value_default1", "bounded_string_value_default2", "bounded_string_value_default3", "bounded_string_value_default4", "bounded_string_value_default5"]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_DEFAULT1_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_DEFAULT2_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_DEFAULT3_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_DEFAULT4_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_DEFAULT5_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_DEFAULT1_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_DEFAULT2_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_DEFAULT3_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_DEFAULT4_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STRING_VALUE_DEFAULT5_FIELD_NUMBER: _ClassVar[int]
    string_value: str
    string_value_default1: str
    string_value_default2: str
    string_value_default3: str
    string_value_default4: str
    string_value_default5: str
    bounded_string_value: str
    bounded_string_value_default1: str
    bounded_string_value_default2: str
    bounded_string_value_default3: str
    bounded_string_value_default4: str
    bounded_string_value_default5: str
    def __init__(self, string_value: _Optional[str] = ..., string_value_default1: _Optional[str] = ..., string_value_default2: _Optional[str] = ..., string_value_default3: _Optional[str] = ..., string_value_default4: _Optional[str] = ..., string_value_default5: _Optional[str] = ..., bounded_string_value: _Optional[str] = ..., bounded_string_value_default1: _Optional[str] = ..., bounded_string_value_default2: _Optional[str] = ..., bounded_string_value_default3: _Optional[str] = ..., bounded_string_value_default4: _Optional[str] = ..., bounded_string_value_default5: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a\x38make87_messages_ros2/jazzy/ibeo_msgs/msg/point2_di.proto\"\xf5\x07\n\nObject2270\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03\x61ge\x18\x02 \x01(\r\x12\x16\n\x0eprediction_age\x18\x03 \x01(\r\x12&\n\x1erelative_moment_of_measurement\x18\x04 \x01(\r\x12 \n\x18reference_point_location\x18\x05 \x01(\r\x12\"\n\x1areference_point_position_x\x18\x06 \x01(\x05\x12\"\n\x1areference_point_position_y\x18\x07 \x01(\x05\x12(\n reference_point_position_sigma_x\x18\x08 \x01(\r\x12(\n reference_point_position_sigma_y\x18\t \x01(\r\x12\x1c\n\x14\x63ontour_points_cog_x\x18\n \x01(\x05\x12\x1c\n\x14\x63ontour_points_cog_y\x18\x0b \x01(\x05\x12\x19\n\x11object_box_length\x18\x0c \x01(\r\x12\x18\n\x10object_box_width\x18\r \x01(\r\x12$\n\x1cobject_box_orientation_angle\x18\x0e \x01(\x05\x12*\n\"object_box_orientation_angle_sigma\x18\x0f \x01(\x05\x12\x1b\n\x13\x61\x62solute_velocity_x\x18\x10 \x01(\x05\x12\x1b\n\x13\x61\x62solute_velocity_y\x18\x11 \x01(\x05\x12!\n\x19\x61\x62solute_velocity_sigma_x\x18\x12 \x01(\r\x12!\n\x19\x61\x62solute_velocity_sigma_y\x18\x13 \x01(\r\x12\x1b\n\x13relative_velocity_x\x18\x14 \x01(\x05\x12\x1b\n\x13relative_velocity_y\x18\x15 \x01(\x05\x12!\n\x19relative_velocity_sigma_x\x18\x16 \x01(\r\x12!\n\x19relative_velocity_sigma_y\x18\x17 \x01(\r\x12\x16\n\x0e\x63lassification\x18\x18 \x01(\r\x12\x16\n\x0etracking_model\x18\x19 \x01(\r\x12\x17\n\x0fmobile_detected\x18\x1a \x01(\x08\x12\x13\n\x0btrack_valid\x18\x1b \x01(\x08\x12\x1a\n\x12\x63lassification_age\x18\x1c \x01(\r\x12!\n\x19\x63lassification_confidence\x18\x1d \x01(\r\x12 \n\x18number_of_contour_points\x18\x1e \x01(\r\x12N\n\x12\x63ontour_point_list\x18\x1f \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Dib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object2270_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT2270']._serialized_start=162
  _globals['_OBJECT2270']._serialized_end=1175
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IwsCmdVWWTVec(_message.Message):
    __slots__ = ["header", "v", "w_f", "w_icc", "delta_t", "state0"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    V_FIELD_NUMBER: _ClassVar[int]
    W_F_FIELD_NUMBER: _ClassVar[int]
    W_ICC_FIELD_NUMBER: _ClassVar[int]
    DELTA_T_FIELD_NUMBER: _ClassVar[int]
    STATE0_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    v: _containers.RepeatedScalarFieldContainer[float]
    w_f: _containers.RepeatedScalarFieldContainer[float]
    w_icc: _containers.RepeatedScalarFieldContainer[float]
    delta_t: _containers.RepeatedScalarFieldContainer[float]
    state0: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., v: _Optional[_Iterable[float]] = ..., w_f: _Optional[_Iterable[float]] = ..., w_icc: _Optional[_Iterable[float]] = ..., delta_t: _Optional[_Iterable[float]] = ..., state0: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_status5.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/delphi_srr_msgs/msg/srr_status5.proto\x12/make87_messages_ros2.humble.delphi_srr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfc\x07\n\nSrrStatus5\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1a\n\x12\x64isable_auto_align\x18\x03 \x01(\x08\x12\x1e\n\x16\x63\x61n_tx_yaw_rate_ref_qf\x18\x04 \x01(\r\x12\x1e\n\x16\x63\x61n_tx_yaw_rate_raw_qf\x18\x05 \x01(\r\x12!\n\x19\x63\x61n_tx_yaw_rate_reference\x18\x06 \x01(\x02\x12\x1b\n\x13\x63\x61n_tx_yaw_rate_raw\x18\x07 \x01(\x02\x12\x1c\n\x14\x63\x61n_tx_system_status\x18\x08 \x01(\r\x12\"\n\x1a\x63\x61n_tx_outside_temperature\x18\t \x01(\x05\x12 \n\x18\x63\x61n_blockage_mnr_blocked\x18\n \x01(\x08\x12\x1f\n\x17\x63\x61n_blockage_bb_blocked\x18\x0b \x01(\x08\x12\"\n\x1a\x63\x61n_blockage_radar_blocked\x18\x0c \x01(\x08\x12\x16\n\x0e\x63\x61n_td_blocked\x18\r \x01(\x08\x12\x1c\n\x14radar_tx_power_error\x18\x0e \x01(\x08\x12\x1c\n\x14radar_lo_power_error\x18\x0f \x01(\x08\x12\x1d\n\x15radar_data_sync_error\x18\x10 \x01(\x08\x12%\n\x1dlinearizer_spi_transfer_error\x18\x11 \x01(\x08\x12#\n\x1bsaturated_tuning_freq_error\x18\x12 \x01(\x08\x12\x1e\n\x16rtn_spi_transfer_error\x18\x13 \x01(\x08\x12\x1e\n\x16rrn_spi_transfer_error\x18\x14 \x01(\x08\x12 \n\x18video_port_capture_error\x18\x15 \x01(\x08\x12#\n\x1bvertical_misalignment_error\x18\x16 \x01(\x08\x12\x1c\n\x14tx_temperature_fault\x18\x17 \x01(\x08\x12\x1c\n\x14transmitter_id_error\x18\x18 \x01(\x08\x12#\n\x1b\x64sp_unit_cal_checksum_error\x18\x19 \x01(\x08\x12\'\n\x1f\x64sp_unit_cal_block_chcksm_error\x18\x1a \x01(\x08\x12$\n\x1c\x64sp_tuning_sensitivity_error\x18\x1b \x01(\x08\x12\x1e\n\x16\x64sp_loop_overrun_error\x18\x1c \x01(\x08\x12\x1e\n\x16\x61\x64\x63_spi_transfer_error\x18\x1d \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_srr_msgs.msg.srr_status5_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRSTATUS5']._serialized_start=209
  _globals['_SRRSTATUS5']._serialized_end=1229
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class OrbAlmInfo(_message.Message):
    __slots__ = ["alm_usability", "alm_source"]
    ALM_USABILITY_FIELD_NUMBER: _ClassVar[int]
    ALM_SOURCE_FIELD_NUMBER: _ClassVar[int]
    alm_usability: int
    alm_source: int
    def __init__(self, alm_usability: _Optional[int] = ..., alm_source: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ChargerState(_message.Message):
    __slots__ = ["charger_time", "state", "charger_name", "error_message", "request_id", "robot_fleet", "robot_name", "time_to_fully_charged"]
    CHARGER_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    CHARGER_NAME_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FLEET_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    TIME_TO_FULLY_CHARGED_FIELD_NUMBER: _ClassVar[int]
    charger_time: _time_pb2.Time
    state: int
    charger_name: str
    error_message: str
    request_id: str
    robot_fleet: str
    robot_name: str
    time_to_fully_charged: _duration_pb2.Duration
    def __init__(self, charger_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., state: _Optional[int] = ..., charger_name: _Optional[str] = ..., error_message: _Optional[str] = ..., request_id: _Optional[str] = ..., robot_fleet: _Optional[str] = ..., robot_name: _Optional[str] = ..., time_to_fully_charged: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NormalizedRegionOfInterest2D(_message.Message):
    __slots__ = ["header", "ros2_header", "xmin", "ymin", "xmax", "ymax", "c"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    XMIN_FIELD_NUMBER: _ClassVar[int]
    YMIN_FIELD_NUMBER: _ClassVar[int]
    XMAX_FIELD_NUMBER: _ClassVar[int]
    YMAX_FIELD_NUMBER: _ClassVar[int]
    C_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    xmin: float
    ymin: float
    xmax: float
    ymax: float
    c: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., xmin: _Optional[float] = ..., ymin: _Optional[float] = ..., xmax: _Optional[float] = ..., ymax: _Optional[float] = ..., c: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WeightedPoseWithCovariance(_message.Message):
    __slots__ = ["pose", "covariance", "weight"]
    POSE_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_pb2.Pose
    covariance: _containers.RepeatedScalarFieldContainer[float]
    weight: float
    def __init__(self, pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., covariance: _Optional[_Iterable[float]] = ..., weight: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/msg/bagfile_progress.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/bagfile_progress.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.msg\"\xc9\x01\n\x0f\x42\x61gfileProgress\x12\x1c\n\x14\x63urrent_bagfile_name\x18\x01 \x01(\t\x12\x1a\n\x12\x63urrent_bagfile_id\x18\x02 \x01(\r\x12\x16\n\x0etotal_bagfiles\x18\x03 \x01(\r\x12\x16\n\x0etotal_messages\x18\x04 \x01(\r\x12\x1a\n\x12processed_messages\x18\x05 \x01(\r\x12\x15\n\rtotal_seconds\x18\x06 \x01(\x02\x12\x19\n\x11processed_seconds\x18\x07 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.msg.bagfile_progress_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BAGFILEPROGRESS']._serialized_start=138
  _globals['_BAGFILEPROGRESS']._serialized_end=339
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.qb_device_msgs.msg import resource_data_pb2 as make87__messages__ros2_dot_humble_dot_qb__device__msgs_dot_msg_dot_resource__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/qb_device_msgs/msg/state.proto\x12.make87_messages_ros2.humble.qb_device_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/qb_device_msgs/msg/resource_data.proto\"\x87\x02\n\x05State\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\tactuators\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.humble.qb_device_msgs.msg.ResourceData\x12L\n\x06joints\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.humble.qb_device_msgs.msg.ResourceData\x12\x13\n\x0bis_reliable\x18\x04 \x01(\x08\x12\x1c\n\x14\x63onsecutive_failures\x18\x05 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=214
  _globals['_STATE']._serialized_end=477
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EstimatorStatus(_message.Message):
    __slots__ = ["header", "attitude_status_flag", "velocity_horiz_status_flag", "velocity_vert_status_flag", "pos_horiz_rel_status_flag", "pos_horiz_abs_status_flag", "pos_vert_abs_status_flag", "pos_vert_agl_status_flag", "const_pos_mode_status_flag", "pred_pos_horiz_rel_status_flag", "pred_pos_horiz_abs_status_flag", "gps_glitch_status_flag", "accel_error_status_flag"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_HORIZ_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_VERT_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    POS_HORIZ_REL_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    POS_HORIZ_ABS_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    POS_VERT_ABS_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    POS_VERT_AGL_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    CONST_POS_MODE_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    PRED_POS_HORIZ_REL_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    PRED_POS_HORIZ_ABS_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    GPS_GLITCH_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    ACCEL_ERROR_STATUS_FLAG_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    attitude_status_flag: bool
    velocity_horiz_status_flag: bool
    velocity_vert_status_flag: bool
    pos_horiz_rel_status_flag: bool
    pos_horiz_abs_status_flag: bool
    pos_vert_abs_status_flag: bool
    pos_vert_agl_status_flag: bool
    const_pos_mode_status_flag: bool
    pred_pos_horiz_rel_status_flag: bool
    pred_pos_horiz_abs_status_flag: bool
    gps_glitch_status_flag: bool
    accel_error_status_flag: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., attitude_status_flag: bool = ..., velocity_horiz_status_flag: bool = ..., velocity_vert_status_flag: bool = ..., pos_horiz_rel_status_flag: bool = ..., pos_horiz_abs_status_flag: bool = ..., pos_vert_abs_status_flag: bool = ..., pos_vert_agl_status_flag: bool = ..., const_pos_mode_status_flag: bool = ..., pred_pos_horiz_rel_status_flag: bool = ..., pred_pos_horiz_abs_status_flag: bool = ..., gps_glitch_status_flag: bool = ..., accel_error_status_flag: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/aid_hui.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/ublox_msgs/msg/aid_hui.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\xc6\x02\n\x06\x41idHUI\x12\x0e\n\x06health\x18\x01 \x01(\r\x12\x0e\n\x06utc_a0\x18\x02 \x01(\x01\x12\x0e\n\x06utc_a1\x18\x03 \x01(\x01\x12\x0f\n\x07utc_tow\x18\x04 \x01(\x05\x12\x0f\n\x07utc_wnt\x18\x05 \x01(\x05\x12\x0e\n\x06utc_ls\x18\x06 \x01(\x05\x12\x0f\n\x07utc_wnf\x18\x07 \x01(\x05\x12\x0e\n\x06utc_dn\x18\x08 \x01(\x05\x12\x0f\n\x07utc_lsf\x18\t \x01(\x05\x12\x11\n\tutc_spare\x18\n \x01(\x05\x12\x0f\n\x07klob_a0\x18\x0b \x01(\x02\x12\x0f\n\x07klob_a1\x18\x0c \x01(\x02\x12\x0f\n\x07klob_a2\x18\r \x01(\x02\x12\x0f\n\x07klob_a3\x18\x0e \x01(\x02\x12\x0f\n\x07klob_b0\x18\x0f \x01(\x02\x12\x0f\n\x07klob_b1\x18\x10 \x01(\x02\x12\x0f\n\x07klob_b2\x18\x11 \x01(\x02\x12\x0f\n\x07klob_b3\x18\x12 \x01(\x02\x12\r\n\x05\x66lags\x18\x13 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.aid_hui_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AIDHUI']._serialized_start=103
  _globals['_AIDHUI']._serialized_end=429
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.controller_manager_msgs.msg import hardware_interface_pb2 as _hardware_interface_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListHardwareInterfacesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListHardwareInterfacesResponse(_message.Message):
    __slots__ = ["command_interfaces", "state_interfaces"]
    COMMAND_INTERFACES_FIELD_NUMBER: _ClassVar[int]
    STATE_INTERFACES_FIELD_NUMBER: _ClassVar[int]
    command_interfaces: _containers.RepeatedCompositeFieldContainer[_hardware_interface_pb2.HardwareInterface]
    state_interfaces: _containers.RepeatedCompositeFieldContainer[_hardware_interface_pb2.HardwareInterface]
    def __init__(self, command_interfaces: _Optional[_Iterable[_Union[_hardware_interface_pb2.HardwareInterface, _Mapping]]] = ..., state_interfaces: _Optional[_Iterable[_Union[_hardware_interface_pb2.HardwareInterface, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_pb2 as _costmap_pb2
from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_meta_data_pb2 as _costmap_meta_data_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetCostmapRequest(_message.Message):
    __slots__ = ["specs"]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    specs: _costmap_meta_data_pb2.CostmapMetaData
    def __init__(self, specs: _Optional[_Union[_costmap_meta_data_pb2.CostmapMetaData, _Mapping]] = ...) -> None: ...

class GetCostmapResponse(_message.Message):
    __slots__ = ["map"]
    MAP_FIELD_NUMBER: _ClassVar[int]
    map: _costmap_pb2.Costmap
    def __init__(self, map: _Optional[_Union[_costmap_pb2.Costmap, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetStateRequest(_message.Message):
    __slots__ = ["time_stamp", "frame_id"]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    time_stamp: _time_pb2.Time
    frame_id: str
    def __init__(self, time_stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., frame_id: _Optional[str] = ...) -> None: ...

class GetStateResponse(_message.Message):
    __slots__ = ["state", "covariance"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    state: _containers.RepeatedScalarFieldContainer[float]
    covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, state: _Optional[_Iterable[float]] = ..., covariance: _Optional[_Iterable[float]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SbgUtcTimeStatus(_message.Message):
    __slots__ = ["clock_stable", "clock_status", "clock_utc_sync", "clock_utc_status"]
    CLOCK_STABLE_FIELD_NUMBER: _ClassVar[int]
    CLOCK_STATUS_FIELD_NUMBER: _ClassVar[int]
    CLOCK_UTC_SYNC_FIELD_NUMBER: _ClassVar[int]
    CLOCK_UTC_STATUS_FIELD_NUMBER: _ClassVar[int]
    clock_stable: bool
    clock_status: int
    clock_utc_sync: bool
    clock_utc_status: int
    def __init__(self, clock_stable: bool = ..., clock_status: _Optional[int] = ..., clock_utc_sync: bool = ..., clock_utc_status: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d_collection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.polygon_msgs.msg import complex_polygon2_d_pb2 as make87__messages__ros2_dot_humble_dot_polygon__msgs_dot_msg_dot_complex__polygon2__d__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d_collection.proto\x12,make87_messages_ros2.humble.polygon_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa8\x02\n\x1a\x43omplexPolygon2DCollection\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x08polygons\x18\x03 \x03(\x0b\x32>.make87_messages_ros2.humble.polygon_msgs.msg.ComplexPolygon2D\x12\x43\n\x06\x63olors\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.polygon_msgs.msg.complex_polygon2_d_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXPOLYGON2DCOLLECTION']._serialized_start=351
  _globals['_COMPLEXPOLYGON2DCOLLECTION']._serialized_end=647
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/publish_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rtabmap_msgs/srv/publish_map.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\"N\n\x11PublishMapRequest\x12\x12\n\nglobal_map\x18\x01 \x01(\x08\x12\x11\n\toptimized\x18\x02 \x01(\x08\x12\x12\n\ngraph_only\x18\x03 \x01(\x08\"\x14\n\x12PublishMapResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.publish_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PUBLISHMAPREQUEST']._serialized_start=110
  _globals['_PUBLISHMAPREQUEST']._serialized_end=188
  _globals['_PUBLISHMAPRESPONSE']._serialized_start=190
  _globals['_PUBLISHMAPRESPONSE']._serialized_end=210
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgANT(_message.Message):
    __slots__ = ["flags", "pins"]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    PINS_FIELD_NUMBER: _ClassVar[int]
    flags: int
    pins: int
    def __init__(self, flags: _Optional[int] = ..., pins: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelRxStatus(_message.Message):
    __slots__ = ["header", "ros2_header", "novatel_msg_header", "error", "rxstat", "aux1stat", "aux2stat", "aux3stat", "aux4stat"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RXSTAT_FIELD_NUMBER: _ClassVar[int]
    AUX1STAT_FIELD_NUMBER: _ClassVar[int]
    AUX2STAT_FIELD_NUMBER: _ClassVar[int]
    AUX3STAT_FIELD_NUMBER: _ClassVar[int]
    AUX4STAT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    error: int
    rxstat: int
    aux1stat: int
    aux2stat: int
    aux3stat: int
    aux4stat: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., error: _Optional[int] = ..., rxstat: _Optional[int] = ..., aux1stat: _Optional[int] = ..., aux2stat: _Optional[int] = ..., aux3stat: _Optional[int] = ..., aux4stat: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/pendulum_msgs/msg/rttest_results.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.pendulum_msgs.msg import joint_command_pb2 as make87__messages__ros2_dot_jazzy_dot_pendulum__msgs_dot_msg_dot_joint__command__pb2
from make87_messages_ros2.jazzy.pendulum_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_pendulum__msgs_dot_msg_dot_joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/pendulum_msgs/msg/rttest_results.proto\x12,make87_messages_ros2.jazzy.pendulum_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a@make87_messages_ros2/jazzy/pendulum_msgs/msg/joint_command.proto\x1a>make87_messages_ros2/jazzy/pendulum_msgs/msg/joint_state.proto\"\xf6\x02\n\rRttestResults\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12K\n\x07\x63ommand\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.jazzy.pendulum_msgs.msg.JointCommand\x12G\n\x05state\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.pendulum_msgs.msg.JointState\x12\x13\n\x0b\x63ur_latency\x18\x04 \x01(\x04\x12\x14\n\x0cmean_latency\x18\x05 \x01(\x01\x12\x13\n\x0bmin_latency\x18\x06 \x01(\x04\x12\x13\n\x0bmax_latency\x18\x07 \x01(\x04\x12\x18\n\x10minor_pagefaults\x18\x08 \x01(\x04\x12\x18\n\x10major_pagefaults\x18\t \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.pendulum_msgs.msg.rttest_results_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RTTESTRESULTS']._serialized_start=308
  _globals['_RTTESTRESULTS']._serialized_end=682
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/constraint_eval_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/moveit_msgs/msg/constraint_eval_result.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\"8\n\x14\x43onstraintEvalResult\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x10\n\x08\x64istance\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.constraint_eval_result_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONSTRAINTEVALRESULT']._serialized_start=123
  _globals['_CONSTRAINTEVALRESULT']._serialized_end=179
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nao_lola_sensor_msgs/msg/sonar.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/nao_lola_sensor_msgs/msg/sonar.proto\x12\x33make87_messages_ros2.jazzy.nao_lola_sensor_msgs.msg\"$\n\x05Sonar\x12\x0c\n\x04left\x18\x01 \x01(\x02\x12\r\n\x05right\x18\x02 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nao_lola_sensor_msgs.msg.sonar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SONAR']._serialized_start=120
  _globals['_SONAR']._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_ship_motion_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/sbg_driver/msg/sbg_ship_motion_status.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\"\xa4\x01\n\x13SbgShipMotionStatus\x12\x13\n\x0bheave_valid\x18\x01 \x01(\x08\x12\x17\n\x0fheave_vel_aided\x18\x02 \x01(\x08\x12\x1b\n\x13surge_sway_included\x18\x03 \x01(\x08\x12\x18\n\x10period_available\x18\x04 \x01(\x08\x12\x14\n\x0cperiod_valid\x18\x05 \x01(\x08\x12\x12\n\nswell_mode\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_ship_motion_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBGSHIPMOTIONSTATUS']._serialized_start=118
  _globals['_SBGSHIPMOTIONSTATUS']._serialized_end=282
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DataPoint(_message.Message):
    __slots__ = ["name_index", "stamp", "value"]
    NAME_INDEX_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name_index: int
    stamp: float
    value: float
    def __init__(self, name_index: _Optional[int] = ..., stamp: _Optional[float] = ..., value: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.autoware_perception_msgs.msg import traffic_light_group_pb2 as _traffic_light_group_pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficLightGroupArray(_message.Message):
    __slots__ = ["stamp", "traffic_light_groups"]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    TRAFFIC_LIGHT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    traffic_light_groups: _containers.RepeatedCompositeFieldContainer[_traffic_light_group_pb2.TrafficLightGroup]
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., traffic_light_groups: _Optional[_Iterable[_Union[_traffic_light_group_pb2.TrafficLightGroup, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto\x12\x33make87_messages_ros2.rolling.rmf_dispenser_msgs.msg\"U\n\x14\x44ispenserRequestItem\x12\x11\n\ttype_guid\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\x18\n\x10\x63ompartment_name\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_dispenser_msgs.msg.dispenser_request_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPENSERREQUESTITEM']._serialized_start=137
  _globals['_DISPENSERREQUESTITEM']._serialized_end=222
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/hil_gps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geo__point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/mavros_msgs/msg/hil_gps.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a>make87_messages_ros2/jazzy/geographic_msgs/msg/geo_point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x96\x02\n\x06HilGPS\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08\x66ix_type\x18\x02 \x01(\r\x12\x45\n\x03geo\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geographic_msgs.msg.GeoPoint\x12\x0b\n\x03\x65ph\x18\x04 \x01(\r\x12\x0b\n\x03\x65pv\x18\x05 \x01(\r\x12\x0b\n\x03vel\x18\x06 \x01(\r\x12\n\n\x02vn\x18\x07 \x01(\x05\x12\n\n\x02ve\x18\x08 \x01(\x05\x12\n\n\x02vd\x18\t \x01(\x05\x12\x0b\n\x03\x63og\x18\n \x01(\r\x12\x1a\n\x12satellites_visible\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.hil_gps_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HILGPS']._serialized_start=223
  _globals['_HILGPS']._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_mrr_msgs/msg/mrr_control_msg_nr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/delphi_mrr_msgs/msg/mrr_control_msg_nr.proto\x12.make87_messages_ros2.jazzy.delphi_mrr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xb0\x02\n\x0fMrrControlMsgNR\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x1f\n\x17\x63\x61n_stop_frequency_nrml\x18\x02 \x01(\r\x12\x1b\n\x13\x63\x61n_prp_factor_nrml\x18\x03 \x01(\r\x12!\n\x19\x63\x61n_desired_sweep_bw_nrml\x18\x04 \x01(\r\x12\x1a\n\x12\x63\x61n_radiation_ctrl\x18\x05 \x01(\x08\x12\x1f\n\x17\x63\x61n_stop_frequency_nrll\x18\x06 \x01(\r\x12\x1b\n\x13\x63\x61n_prp_factor_nrll\x18\x07 \x01(\r\x12!\n\x19\x63\x61n_desired_sweep_bw_nrll\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_mrr_msgs.msg.mrr_control_msg_nr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MRRCONTROLMSGNR']._serialized_start=178
  _globals['_MRRCONTROLMSGNR']._serialized_end=482
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import marker_pb2 as _marker_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InteractiveMarkerControl(_message.Message):
    __slots__ = ["name", "orientation", "orientation_mode", "interaction_mode", "always_visible", "markers", "independent_marker_orientation", "description"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_MODE_FIELD_NUMBER: _ClassVar[int]
    INTERACTION_MODE_FIELD_NUMBER: _ClassVar[int]
    ALWAYS_VISIBLE_FIELD_NUMBER: _ClassVar[int]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    INDEPENDENT_MARKER_ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    orientation: _quaternion_pb2.Quaternion
    orientation_mode: int
    interaction_mode: int
    always_visible: bool
    markers: _containers.RepeatedCompositeFieldContainer[_marker_pb2.Marker]
    independent_marker_orientation: bool
    description: str
    def __init__(self, name: _Optional[str] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., orientation_mode: _Optional[int] = ..., interaction_mode: _Optional[int] = ..., always_visible: bool = ..., markers: _Optional[_Iterable[_Union[_marker_pb2.Marker, _Mapping]]] = ..., independent_marker_orientation: bool = ..., description: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_scheduler_msgs/msg/schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_scheduler_msgs.msg import payload_pb2 as make87__messages__ros2_dot_humble_dot_rmf__scheduler__msgs_dot_msg_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/rmf_scheduler_msgs/msg/schedule.proto\x12\x32make87_messages_ros2.humble.rmf_scheduler_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rmf_scheduler_msgs/msg/payload.proto\"\xee\x01\n\x08Schedule\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12\x10\n\x08start_at\x18\x05 \x01(\x03\x12\x11\n\tfinish_at\x18\x06 \x01(\x03\x12\r\n\x05group\x18\x07 \x01(\t\x12L\n\x07payload\x18\x08 \x01(\x0b\x32;.make87_messages_ros2.humble.rmf_scheduler_msgs.msg.Payloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_scheduler_msgs.msg.schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULE']._serialized_start=223
  _globals['_SCHEDULE']._serialized_end=461
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import parameter_pb2 as _parameter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterEvent(_message.Message):
    __slots__ = ["header", "stamp", "node", "new_parameters", "changed_parameters", "deleted_parameters"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    NEW_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CHANGED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    DELETED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stamp: _time_pb2.Time
    node: str
    new_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    changed_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    deleted_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., node: _Optional[str] = ..., new_parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ..., changed_parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ..., deleted_parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/object_recognition_msgs/msg/object_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_humble_dot_shape__msgs_dot_msg_dot_mesh__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/object_recognition_msgs/msg/object_information.proto\x12\x37make87_messages_ros2.humble.object_recognition_msgs.msg\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/shape_msgs/msg/mesh.proto\"\xf8\x01\n\x11ObjectInformation\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\x11ground_truth_mesh\x18\x03 \x01(\x0b\x32\x30.make87_messages_ros2.humble.shape_msgs.msg.Mesh\x12Z\n\x18ground_truth_point_cloud\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.object_recognition_msgs.msg.object_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTINFORMATION']._serialized_start=296
  _globals['_OBJECTINFORMATION']._serialized_end=544
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import string_pb2 as _string_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SaveMapRequest(_message.Message):
    __slots__ = ["filename"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    filename: _string_pb2.String
    def __init__(self, filename: _Optional[_Union[_string_pb2.String, _Mapping]] = ...) -> None: ...

class SaveMapResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/novatel_gps_msgs/msg/range_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/novatel_gps_msgs/msg/range_information.proto\x12/make87_messages_ros2.jazzy.novatel_gps_msgs.msg\"\xc9\x01\n\x10RangeInformation\x12\x12\n\nprn_number\x18\x01 \x01(\r\x12\x0f\n\x07glofreq\x18\x02 \x01(\r\x12\x0b\n\x03psr\x18\x03 \x01(\x01\x12\x0f\n\x07psr_std\x18\x04 \x01(\x02\x12\x0b\n\x03\x61\x64r\x18\x05 \x01(\x01\x12\x0f\n\x07\x61\x64r_std\x18\x06 \x01(\x02\x12\x0c\n\x04\x64opp\x18\x07 \x01(\x02\x12\x1b\n\x13noise_density_ratio\x18\x08 \x01(\x02\x12\x10\n\x08locktime\x18\t \x01(\x02\x12\x17\n\x0ftracking_status\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.novatel_gps_msgs.msg.range_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RANGEINFORMATION']._serialized_start=125
  _globals['_RANGEINFORMATION']._serialized_end=326
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationRepeat(_message.Message):
    __slots__ = ["conflict_version", "table"]
    CONFLICT_VERSION_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    conflict_version: int
    table: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, conflict_version: _Optional[int] = ..., table: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.shape_msgs.msg import mesh_pb2 as _mesh_pb2
from make87_messages_ros2.jazzy.shape_msgs.msg import solid_primitive_pb2 as _solid_primitive_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoundingVolume(_message.Message):
    __slots__ = ["primitives", "primitive_poses", "meshes", "mesh_poses"]
    PRIMITIVES_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_POSES_FIELD_NUMBER: _ClassVar[int]
    MESHES_FIELD_NUMBER: _ClassVar[int]
    MESH_POSES_FIELD_NUMBER: _ClassVar[int]
    primitives: _containers.RepeatedCompositeFieldContainer[_solid_primitive_pb2.SolidPrimitive]
    primitive_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    meshes: _containers.RepeatedCompositeFieldContainer[_mesh_pb2.Mesh]
    mesh_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    def __init__(self, primitives: _Optional[_Iterable[_Union[_solid_primitive_pb2.SolidPrimitive, _Mapping]]] = ..., primitive_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., meshes: _Optional[_Iterable[_Union[_mesh_pb2.Mesh, _Mapping]]] = ..., mesh_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_layers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_layers.proto\x12\x32make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv\"\x12\n\x10GetLayersRequest\"#\n\x11GetLayersResponse\x12\x0e\n\x06layers\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv.get_layers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETLAYERSREQUEST']._serialized_start=123
  _globals['_GETLAYERSREQUEST']._serialized_end=141
  _globals['_GETLAYERSRESPONSE']._serialized_start=143
  _globals['_GETLAYERSRESPONSE']._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/srv/register_participant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import participant_description_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_participant__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/rmf_traffic_msgs/srv/register_participant.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.srv\x1aMmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participant_description.proto\"z\n\x1aRegisterParticipantRequest\x12\\\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32G.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.ParticipantDescription\"\x95\x01\n\x1bRegisterParticipantResponse\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\x12\x1e\n\x16last_itinerary_version\x18\x02 \x01(\x04\x12\x14\n\x0clast_plan_id\x18\x03 \x01(\x04\x12\x19\n\x11next_storage_base\x18\x04 \x01(\x04\x12\r\n\x05\x65rror\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.srv.register_participant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGISTERPARTICIPANTREQUEST']._serialized_start=206
  _globals['_REGISTERPARTICIPANTREQUEST']._serialized_end=328
  _globals['_REGISTERPARTICIPANTRESPONSE']._serialized_start=331
  _globals['_REGISTERPARTICIPANTRESPONSE']._serialized_end=480
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MultiArrayDimension(_message.Message):
    __slots__ = ["label", "size", "stride"]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    STRIDE_FIELD_NUMBER: _ClassVar[int]
    label: str
    size: int
    stride: int
    def __init__(self, label: _Optional[str] = ..., size: _Optional[int] = ..., stride: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeneralSystemState(_message.Message):
    __slots__ = ["header", "run_mode_active", "standby_mode_active", "contamination_warning", "contamination_error", "reference_contour_status", "manipulation_status", "safe_cut_off_path", "non_safe_cut_off_path", "reset_required_cut_off_path", "current_monitoring_case_no_table_1", "current_monitoring_case_no_table_2", "current_monitoring_case_no_table_3", "current_monitoring_case_no_table_4", "application_error", "device_error"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RUN_MODE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STANDBY_MODE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_CONTOUR_STATUS_FIELD_NUMBER: _ClassVar[int]
    MANIPULATION_STATUS_FIELD_NUMBER: _ClassVar[int]
    SAFE_CUT_OFF_PATH_FIELD_NUMBER: _ClassVar[int]
    NON_SAFE_CUT_OFF_PATH_FIELD_NUMBER: _ClassVar[int]
    RESET_REQUIRED_CUT_OFF_PATH_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MONITORING_CASE_NO_TABLE_1_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MONITORING_CASE_NO_TABLE_2_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MONITORING_CASE_NO_TABLE_3_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MONITORING_CASE_NO_TABLE_4_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    run_mode_active: bool
    standby_mode_active: bool
    contamination_warning: bool
    contamination_error: bool
    reference_contour_status: bool
    manipulation_status: bool
    safe_cut_off_path: _containers.RepeatedScalarFieldContainer[bool]
    non_safe_cut_off_path: _containers.RepeatedScalarFieldContainer[bool]
    reset_required_cut_off_path: _containers.RepeatedScalarFieldContainer[bool]
    current_monitoring_case_no_table_1: int
    current_monitoring_case_no_table_2: int
    current_monitoring_case_no_table_3: int
    current_monitoring_case_no_table_4: int
    application_error: bool
    device_error: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., run_mode_active: bool = ..., standby_mode_active: bool = ..., contamination_warning: bool = ..., contamination_error: bool = ..., reference_contour_status: bool = ..., manipulation_status: bool = ..., safe_cut_off_path: _Optional[_Iterable[bool]] = ..., non_safe_cut_off_path: _Optional[_Iterable[bool]] = ..., reset_required_cut_off_path: _Optional[_Iterable[bool]] = ..., current_monitoring_case_no_table_1: _Optional[int] = ..., current_monitoring_case_no_table_2: _Optional[int] = ..., current_monitoring_case_no_table_3: _Optional[int] = ..., current_monitoring_case_no_table_4: _Optional[int] = ..., application_error: bool = ..., device_error: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FieldInformation(_message.Message):
    __slots__ = ["header", "field_id", "field_set_id", "field_result", "eval_method", "field_active"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FIELD_ID_FIELD_NUMBER: _ClassVar[int]
    FIELD_SET_ID_FIELD_NUMBER: _ClassVar[int]
    FIELD_RESULT_FIELD_NUMBER: _ClassVar[int]
    EVAL_METHOD_FIELD_NUMBER: _ClassVar[int]
    FIELD_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    field_id: int
    field_set_id: int
    field_result: int
    eval_method: int
    field_active: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., field_id: _Optional[int] = ..., field_set_id: _Optional[int] = ..., field_result: _Optional[int] = ..., eval_method: _Optional[int] = ..., field_active: _Optional[int] = ...) -> None: ...
